#
# spec file for package elisa
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without lang

%define qt5_version 5.10.0
%define kf5_version 5.45.0

Name:           elisa
Version:        0.3.0
Release:        1.1
Summary:        Music player and collection organizer
License:        LGPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
Url:            https://community.kde.org/Elisa
Source0:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz
Source1:        https://download.kde.org/stable/%{name}/%{version}/%{name}-%{version}.tar.xz.sig
Source2:        %{name}.keyring
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Baloo) >= %{kf5_version}
BuildRequires:  cmake(KF5Config) >= %{kf5_version}
BuildRequires:  cmake(KF5ConfigWidgets) >= %{kf5_version}
BuildRequires:  cmake(KF5CoreAddons) >= %{kf5_version}
BuildRequires:  cmake(KF5Crash) >= %{kf5_version}
BuildRequires:  cmake(KF5DBusAddons) >= %{kf5_version}
BuildRequires:  cmake(KF5Declarative) >= %{kf5_version}
BuildRequires:  cmake(KF5DocTools) >= %{kf5_version}
BuildRequires:  cmake(KF5FileMetaData) >= %{kf5_version}
BuildRequires:  cmake(KF5I18n) >= %{kf5_version}
BuildRequires:  cmake(KF5KCMUtils) >= %{kf5_version}
BuildRequires:  cmake(KF5KIO) >= %{kf5_version}
BuildRequires:  cmake(KF5Package) >= %{kf5_version}
BuildRequires:  cmake(KF5XmlGui) >= %{kf5_version}
BuildRequires:  pkgconfig(Qt5Concurrent) >= %{qt5_version}
BuildRequires:  pkgconfig(Qt5Core) >= %{qt5_version}
BuildRequires:  pkgconfig(Qt5DBus) >= %{qt5_version}
BuildRequires:  pkgconfig(Qt5Gui) >= %{qt5_version}
BuildRequires:  pkgconfig(Qt5Multimedia) >= %{qt5_version}
BuildRequires:  pkgconfig(Qt5Network) >= %{qt5_version}
BuildRequires:  pkgconfig(Qt5Qml) >= %{qt5_version}
BuildRequires:  pkgconfig(Qt5QuickControls2) >= %{qt5_version}
BuildRequires:  pkgconfig(Qt5Quick) >= %{qt5_version}
BuildRequires:  pkgconfig(Qt5Sql) >= %{qt5_version}
BuildRequires:  pkgconfig(Qt5Svg) >= %{qt5_version}
BuildRequires:  pkgconfig(Qt5Test) >= %{qt5_version}
BuildRequires:  pkgconfig(Qt5Widgets) >= %{qt5_version}
Requires:       kdeclarative-components >= %{kf5_version}
Requires:       libqt5-qtquickcontrols >= %{qt5_version}
Requires:       libqt5-qtquickcontrols2 >= %{qt5_version}
%if %{with lang}
Recommends:     %{name}-lang
%endif

%description
Elisa is a music player with a library where music can be browsed by
album, artist or all tracks. It is indexed using either a private
indexer or an indexer using Baloo. The private one can be configured
to scan music on chosen paths. The Baloo one is faster because Baloo
is providing all needed data from its own database. Playlists can be
built and played.

%if %{with lang}
%lang_package
%endif

%prep
%setup -q

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build
  %if %{with lang}
    %find_lang %{name} --with-man --all-name
    %{kf5_find_htmldocs}
  %endif
  %suse_update_desktop_file -r org.kde.elisa Qt KDE AudioVideo Audio Player

%files
%license COPYING*
%doc README*
%doc %lang(en) %{_kf5_htmldir}/en/elisa/
%{_kf5_bindir}/elisa
%{_kf5_applicationsdir}/org.kde.elisa.desktop
%{_kf5_libdir}/elisa/
%dir %{_kf5_plugindir}/kcms
%{_kf5_plugindir}/kcms/kcm_elisa_local_file.so
%{_kf5_qmldir}/org/kde/elisa/
%{_kf5_iconsdir}/hicolor/*/apps/elisa.*
%{_kf5_appstreamdir}/org.kde.elisa.appdata.xml
%dir %{_kf5_sharedir}/kpackage
%dir %{_kf5_sharedir}/kpackage/kcms
%dir %{_kf5_sharedir}/kpackage/kcms/kcm_elisa_local_file
%{_kf5_sharedir}/kpackage/kcms/kcm_elisa_local_file/contents.rcc
%{_kf5_sharedir}/kpackage/kcms/kcm_elisa_local_file/metadata.json
%{_kf5_servicesdir}/kcm_elisa_local_file.desktop

%if %{with lang}
%files lang -f %{name}.lang
%endif

%changelog
* Sun Sep 30 2018 wbauer@tmo.at
- Update to 0.3.0
  * Fix scrolling in the Album, Artist, etc. and Now Playing views
    is much too fast (kde#397446)
  * Fix status box is too small (kde#398924)
  * Fix Elisa being unaware of Baloo if it starts after Elisa
    (kde#387437)
  * User should be able to start typing to search after pressing
    Ctrl+F (kde#398718)
  * Fix high memory usage (kde#396840)
    (improvements have landed in 0.3.0 release and more will come
    to 0.3.1)
  * Elisa should better handle being scaled down to a small size
    (kde#392778)
    (not yet finished but some improvements are in 0.3.0 release)
  * Hide stars when there is no rating
  * Implement interface of Baloo to watch renamed files
  * Upgrade some code using deprecated features in KDeclarative
    framework
  * Align the action buttons with the big icon in the views header
  * Allow the playlist to be hidden when browsing your music
  * Always display the title of the playlist entries
  * Internal improvements to various non graphical components to
    allow future improvements to the header bar
  * Resize track metadata view dynamically
  * Improvements to the header of the play list
  * Add a mode where Elisa can show only the header but in the full
    window
  * Optimize the data methods of model and use
    QAbstractItemModelTester
  * Makes KIO and KFileMetaData be optional dependencies
* Sun Sep 16 2018 wbauer@tmo.at
- Update to 0.2.1
  * Fixed issues that could lead to wrong data shown for albums
    with multiple discs
  * The buttons in the header on top of the views are now aligned
    with the top and bottom of the big icon
- Update to 0.2.0
  * All views are now sorted in ascending order by default
  * New button to toggle between ascending and descending
  * New view allows you to browse your home directory, only music
    files and directories are shown
  * New view allows you to browse by going from genres to artists,
    their albums and its tracks
  * Now has a proper icon
  * The player bar is now featuring all playback controls, the look
    of the playlist view and the views selector have been refreshed
    and improved
  * Now uses the new icons from Breeze to differentiate between
    actions (play, pause, etc) and states (playing, paused, etc)
  * To avoid scanning files for changes at the start, Elisa now
    keeps the last modified time of files
  * The browsing views are now only loaded when shown
  * Elisa is now finding more cover images and most common cases
    should work
  * A few fixes to Mpris2 support
  * Various fixes to the internal tracks database
- Use macros for the minimum Qt5 and KF5 versions in the specfile
* Tue Apr 17 2018 kbabioch@suse.com
- Update to 0.1.1
  * Minor bugfixes
- Download and verify signature for source archive
- Cleaned up spec file (spec-cleaner)
* Sun Apr  8 2018 wbauer@tmo.at
- Update to 0.1
  * First stable release
- Update build requirements
- Add necessary runtime requirements
- Mark license files as %%license instead of %%doc
* Mon Feb  5 2018 jengelh@inai.de
- Ensure neutrality of description.
- Replace vision statement by what the software is about.
* Fri Feb  2 2018 kbabioch@suse.com
- Initial packaging of elisa
